﻿using Syncfusion.Presentation;
using System;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.IO;

namespace Create_Slide_Thumbnails.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            return View();
        }

        //Method to create thumbnail image and save it in specified location
        public ActionResult CreateThumbnails()
        {
            //Load the existing PowerPoint Presentation
            using (IPresentation pptxDoc = Presentation.Open(ResolveApplicationDataPath("/") + "GettingStarted.pptx"))
            {
                //Load each slide in PowerPoint
                foreach (ISlide slide in pptxDoc.Slides)
                {
                    //Conver the PowerPoint slide to image
                    Image image = slide.ConvertToImage(Syncfusion.Drawing.ImageType.Bitmap);

                    //Set the size for image
                    Size size = new Size(200, 200);

                    //Create new Bitmap image with spcified size for converted image.
                    Bitmap bitmap = new Bitmap(image, size);

                    //Save the image in specified location
                    bitmap.Save(ResolveApplicationOutputPath("/") + "image" + Guid.NewGuid().ToString() + ".jpeg", System.Drawing.Imaging.ImageFormat.Jpeg);
                }
            }

            return View();
        }

        public ActionResult About()
        {
            ViewBag.Message = "Your application description page.";

            return View();
        }

        public ActionResult Contact()
        {
            ViewBag.Message = "Your contact page.";

            return View();
        }

        /// <summary>
        /// Get the data path location
        /// </summary>
        /// <param name=" fileName">Specifies the file which should get opened for conversion</param>
        protected string ResolveApplicationDataPath(string fileName)
        {
            //Data folder path is resolved from requested page physical path.
            string dataPath = new System.IO.DirectoryInfo(Request.PhysicalPath + "..\\..\\..\\Data\\").FullName;
            return string.Format("{0}\\{1}", dataPath, fileName);
        }

        /// <summary>
        ///  Gets the converted image storage location
        /// </summary>
        /// <param name=" fileName">Specifies the physical folder path of image storage location</param>
        protected string ResolveApplicationOutputPath(string fileName)
        {
            //Data folder path is resolved from requested page physical path.
            string dataPath = new System.IO.DirectoryInfo(Request.PhysicalPath + "..\\..\\..\\Output Images\\").FullName;
            return string.Format("{0}\\{1}", dataPath, fileName);
        }
    }
}